@@ -1,7 +1,18 @@
+from numbers import Number
+
 import numpy as np
 
 
+def _find_nearest(array, value):
+    array = np.asarray(array)
+    idx = (np.abs(array - value)).argmin()
+    return idx
+
+
 def argclosest(array, values):
+    if isinstance(values, Number):
+        return _find_nearest(array, values)
+
     # https://stackoverflow.com/questions/2566412/
     # find-nearest-value-in-numpy-array
     array = np.array(array)
